# CHANGELOG


## v0.0.1 (2024-12-11)

### Bug Fixes

* fix: add pypi badge ([`170119f`](https://github.com/COMPAS-Surrogate/ogc4_interface/commit/170119f45dc4d1f9a13236b958384bb482d47916))


## v0.0.0 (2024-12-11)

### Chores

* chore(release): 0.0.0 ([`136fbf5`](https://github.com/COMPAS-Surrogate/ogc4_interface/commit/136fbf5027f2206e63b8783d4f4194f93d44fff7))

### Unknown

* patch: add dynamic versioning and CD ([`38ed9a6`](https://github.com/COMPAS-Surrogate/ogc4_interface/commit/38ed9a6f50d18f00cab35b5f602f3cbddcad909a))

* update pycbc ([`84c1c04`](https://github.com/COMPAS-Surrogate/ogc4_interface/commit/84c1c04a8f37c8e5737bee44e44d0cabeae80bb0))

* run isort ([`907b31e`](https://github.com/COMPAS-Surrogate/ogc4_interface/commit/907b31e68846b8a9e763741385473ea026474179))

* run blck ([`998a725`](https://github.com/COMPAS-Surrogate/ogc4_interface/commit/998a725a9ef6683c34fe29d1d82f2137ea8c6c9d))

* add duration for the dataset ([`3187cdb`](https://github.com/COMPAS-Surrogate/ogc4_interface/commit/3187cdb40585a446c641fcacda6a6322658519ce))

* add more filterint options ([`73fb01c`](https://github.com/COMPAS-Surrogate/ogc4_interface/commit/73fb01c413ad5a8a15511e1c3dce1f6e2470876d))

* update events ([`0d08280`](https://github.com/COMPAS-Surrogate/ogc4_interface/commit/0d08280508c7639623b2fd427342fd56a2b300be))

* add additional run check ([`6b75035`](https://github.com/COMPAS-Surrogate/ogc4_interface/commit/6b750358bb1d1a57746265cc939a0a8b1620b844))

* update imaages ([`f39ba04`](https://github.com/COMPAS-Surrogate/ogc4_interface/commit/f39ba049948222278ceb70af4c3f733cf896ae8d))

* fix pathing ([`f1a15e5`](https://github.com/COMPAS-Surrogate/ogc4_interface/commit/f1a15e5f9ff26249c8154329d16d2e7936db5dea))

* add colormath ([`195121a`](https://github.com/COMPAS-Surrogate/ogc4_interface/commit/195121aa7f249b181d1713abc00ee727dd04dbea))

* add docs ([`acf4e38`](https://github.com/COMPAS-Surrogate/ogc4_interface/commit/acf4e38620efba3c13028bb3785d88bd1315d05b))

* add install ([`5c02bf8`](https://github.com/COMPAS-Surrogate/ogc4_interface/commit/5c02bf8adc6a55000649bd97849513219dc3ab7f))

* add installs ([`e169ace`](https://github.com/COMPAS-Surrogate/ogc4_interface/commit/e169ace70cddc327ff42cd23d44b34c428c69e6e))

* decode GW-name correctly from hdf ([`1104c7b`](https://github.com/COMPAS-Surrogate/ogc4_interface/commit/1104c7bcbfbfb0abcb72b1cc113ee6e9f6d9503c))

* decode GW-name correctly from hdf ([`401ca77`](https://github.com/COMPAS-Surrogate/ogc4_interface/commit/401ca7789c6d96d2688a7019f13abb9e014d7e4c))

* upload weights ([`2c94e2c`](https://github.com/COMPAS-Surrogate/ogc4_interface/commit/2c94e2c82bb025781321927b5543d9534cead752))

* add weights ([`d27e0c6`](https://github.com/COMPAS-Surrogate/ogc4_interface/commit/d27e0c63d4f217d6ccd346b979262058fdbcb2ec))

* run precommits ([`ad40eb8`](https://github.com/COMPAS-Surrogate/ogc4_interface/commit/ad40eb8289965ea6e921fc924bb030d388a5a58a))

* add plotters for events ([`8a0c127`](https://github.com/COMPAS-Surrogate/ogc4_interface/commit/8a0c127c72f5f8053387b9b73db70e82d67b835a))

* add events ([`2f995d0`](https://github.com/COMPAS-Surrogate/ogc4_interface/commit/2f995d0404bd008e780440e6c56c62325ef3d786))

* add mc-z in bin check ([`3646281`](https://github.com/COMPAS-Surrogate/ogc4_interface/commit/3646281b5ef34ecbd0cac5c9d664464472d3a536))

* add plotting fixes ([`e022f9d`](https://github.com/COMPAS-Surrogate/ogc4_interface/commit/e022f9d4fcae72e18723588a023f372bee3890d4))

* add tests and plots ([`42e22a9`](https://github.com/COMPAS-Surrogate/ogc4_interface/commit/42e22a9b4b0728d85f701a1e4a6824ca8fe20064))

* add cosmology ([`c4aeaff`](https://github.com/COMPAS-Surrogate/ogc4_interface/commit/c4aeaff937862f20a2a24d552b1429e0d104f294))

* init priors ([`420f56b`](https://github.com/COMPAS-Surrogate/ogc4_interface/commit/420f56b32fb815a69fa9cada02ef34bd81d780eb))

* Update README.md ([`12281b0`](https://github.com/COMPAS-Surrogate/ogc4_interface/commit/12281b0b901a958371a5c0cb75d45418dfc2e8c5))

* Update README.md ([`ff1aa18`](https://github.com/COMPAS-Surrogate/ogc4_interface/commit/ff1aa189e0800154307c2d94f40e49fa2ac40716))

* Initial commit ([`b83cb98`](https://github.com/COMPAS-Surrogate/ogc4_interface/commit/b83cb98098737fc1ffa17059f9f47df48f2b67a1))
